/*
 * PEAK-SEQ -- PREPROCESSING
 * Paper by Joel Rozowsky, et. al.
 * Coded in C by Theodore Gibson.
 * This file contains all of the parameters for the program
 * including input and output file locations.
*/


// Average length of DNA fragments.
#define READ_LENGTH 200


// The following are used to construct filenames.
// A string of the format chr1 to chrM is placed between
// the PREFIX and SUFFIX of each filename.
// The Eland file containing all chromosomes.
#define INPUT_FILENAME "PolII/short_PolII.txt"
// The sample Eland files to be outputted.
#define ELAND_PREFIX "PolII/sgr_files/short_PolII_eland_result."
#define ELAND_SUFFIX ".txt"
// The sample sgr files to be outputted.
#define SGR_PREFIX "PolII/sgr_files/short_PolII."
#define SGR_SUFFIX ".sgr"

// Parameters and calculations based on parameters that are
// not to be changed.
// The first chromosome used. (23 is X, 24 is Y, 25 is M.) 
#define MIN_CNUM 1
// The last chromosome used. (23 is X, 24 is Y, 25 is M.)
#define MAX_CNUM 25
// The total number of chromosomes used in the program.
#define N_CHRS (MAX_CNUM - MIN_CNUM + 1)
// The maximum number of characters in a filename.
#define FILENAME_LENGTH 200
// The score of a start position of a read used in determining
// the aggregate height of a position.
#define START 1
// The score of a stop position of a read used in determining
// the aggregate height of a position.
#define STOP -1
